@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: dwmdns.cc 10143 2018-01-28 19:12:01Z dwm $
+// @(#) $Id: dwmdns.cc 10719 2020-05-06 19:43:39Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2018
 //  All rights reserved.
@@ -48,7 +48,7 @@
 #include "DwmDnsResolver.hh"
 #include "DwmDnsUtils.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.1.1/apps/dwmdns/dwmdns.cc 10143 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.1/apps/dwmdns/dwmdns.cc 10719 $");
 
 using namespace std;
 using namespace Dwm;
@@ -189,9 +189,8 @@ int main(int argc, char *argv[])
   string  server = optArgs.Get<string>('s');
   if (! server.empty()) {
     try {
-      Dns::NameServer  ns(server);
       resolver.NameServers().clear();
-      resolver.NameServers().push_back(ns);
+      resolver.NameServers().push_back(Dns::NameServer(server));
     }
     catch (std::exception & ex) {
       cerr << ex.what() << '\n';
