@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.1.1/classes/src/DwmDnsNameServer.cc 10150 $
-// @(#) $Id: DwmDnsNameServer.cc 10150 2018-01-31 05:18:38Z dwm $
+// @(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.1/classes/src/DwmDnsNameServer.cc 10735 $
+// @(#) $Id: DwmDnsNameServer.cc 10735 2020-05-07 18:18:27Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017, 2018
 //  All rights reserved.
@@ -55,13 +55,55 @@ extern "C" {
 #include "DwmSysLogger.hh"
 #include "DwmDnsNameServer.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.1.1/classes/src/DwmDnsNameServer.cc 10150 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.1/classes/src/DwmDnsNameServer.cc 10735 $");
 
 using namespace std;
 
 namespace Dwm {
 
   namespace Dns {
+
+    //------------------------------------------------------------------------
+    //!  
+    //------------------------------------------------------------------------
+    NameServer::NameServer()
+        : _addrFamily(AF_INET), _udpfd(-1), _tcpfd(-1)
+    {
+      memset(&_addr, 0, sizeof(_addr));      
+    }
+
+    //------------------------------------------------------------------------
+    //!  
+    //------------------------------------------------------------------------
+    NameServer::NameServer(NameServer && ns) noexcept
+        : _udpfd(std::exchange(ns._udpfd, -1)),
+          _tcpfd(std::exchange(ns._tcpfd, -1)),
+          _addrFamily(std::exchange(ns._addrFamily, AF_INET))
+    {
+      memcpy(&_addr, &ns._addr, sizeof(_addr));
+      memset(&ns._addr, 0, sizeof(ns._addr));
+    }
+
+    //------------------------------------------------------------------------
+    //!  
+    //------------------------------------------------------------------------
+    NameServer & NameServer::operator = (NameServer && ns) noexcept
+    {
+      if (0 <= _udpfd) {
+        close(_udpfd);
+      }
+      _udpfd = std::exchange(ns._udpfd, -1);
+      if (0 <= _tcpfd) {
+        close(_tcpfd);
+      }
+      _tcpfd = std::exchange(ns._tcpfd, -1);
+      
+      _addrFamily = std::exchange(ns._addrFamily, AF_INET);
+      memcpy(&_addr, &ns._addr, sizeof(_addr));
+      memset(&ns._addr, 0, sizeof(ns._addr));
+      
+      return *this;
+    }
     
     //------------------------------------------------------------------------
     //!  
@@ -77,7 +119,22 @@ namespace Dwm {
       _addr.in4Addr.sin_len = sizeof(_addr.in4Addr);
 #endif
     }
-    
+
+    //------------------------------------------------------------------------
+    //!  
+    //------------------------------------------------------------------------
+    NameServer::NameServer(const Ipv4Address & addr)
+        : _addrFamily(AF_INET), _udpfd(-1), _tcpfd(-1)
+    {
+      memset(&_addr, 0, sizeof(_addr));
+      _addr.in4Addr.sin_family = AF_INET;
+      _addr.in4Addr.sin_addr.s_addr = addr.Raw();
+      _addr.in4Addr.sin_port = htons(53);
+#ifndef __linux__
+      _addr.in4Addr.sin_len = sizeof(_addr.in4Addr);
+#endif
+    }
+
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
@@ -122,6 +179,7 @@ namespace Dwm {
           _addrFamily = AF_INET;
         }
         else {
+          Syslog(LOG_ERR, "invalid address for NameServer %s", addr.c_str());
           throw std::invalid_argument("invalid address for NameServer");
         }
       }
