@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: DwmDnsResolver.cc 10073 2018-01-25 00:36:29Z dwm $
+// @(#) $Id: DwmDnsResolver.cc 10719 2020-05-06 19:43:39Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2018
 //  All rights reserved.
@@ -44,7 +44,7 @@
 #include "DwmDnsResolvConf.hh"
 #include "DwmDnsUtils.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.1.1/classes/src/DwmDnsResolver.cc 10073 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.1/classes/src/DwmDnsResolver.cc 10719 $");
 
 using namespace std;
 
@@ -64,7 +64,7 @@ namespace Dwm {
       }
       ResolvConf  resconf(filename);
       for (auto & ns : resconf.Nameservers()) {
-        _nameservers.push_back(ns);
+        _nameservers.push_back(std::move(ns));
       }
       for (auto & sle : resconf.SearchList()) {
         _searchList.push_back(sle);
