@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: TestDnsNameServer.cc 10560 2020-04-24 23:01:10Z dwm $
+// @(#) $Id: TestDnsNameServer.cc 10734 2020-05-07 18:13:40Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2018
 //  All rights reserved.
@@ -50,7 +50,7 @@ extern "C" {
 #include "DwmUnitAssert.hh"
 #include "DwmDnsNameServer.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.1.1/classes/tests/TestDnsNameServer.cc 10560 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.1/classes/tests/TestDnsNameServer.cc 10734 $");
 
 using namespace std;
 using namespace Dwm;
@@ -67,9 +67,7 @@ void TestGoogleA()
                                  Dns::MessageQuestion::k_classIN);
   message.Questions().push_back(question);
 
-  in_addr  inAddr;
-  inet_pton(AF_INET, "8.8.8.8", &inAddr);
-  Dns::NameServer  nameServer(inAddr);
+  Dns::NameServer  nameServer(Ipv4Address("8.8.8.8"));
   if (UnitAssert(nameServer.SendMessage(message) > 0)) {
     UnitAssert(nameServer.ReceiveMessage(message));
     UnitAssert(message.Questions().size() > 0);
@@ -96,9 +94,7 @@ void TestGoogleAAAA()
                                  Dns::MessageQuestion::k_classIN);
   message.Questions().push_back(question);
 
-  in_addr  inAddr;
-  inet_pton(AF_INET, "8.8.8.8", &inAddr);
-  Dns::NameServer  nameServer(inAddr);
+  Dns::NameServer  nameServer(Ipv4Address("8.8.8.8"));
   if (UnitAssert(nameServer.SendMessage(message) > 0)) {
     UnitAssert(nameServer.ReceiveMessage(message));
     UnitAssert(message.Questions().size() > 0);
@@ -123,9 +119,7 @@ void TestGoogleSOA()
                                  Dns::MessageQuestion::k_classIN);
   message.Questions().push_back(question);
 
-  in_addr  inAddr;
-  inet_pton(AF_INET, "8.8.8.8", &inAddr);
-  Dns::NameServer  nameServer(inAddr);
+  Dns::NameServer  nameServer(Ipv4Address("8.8.8.8"));
   if (UnitAssert(nameServer.SendMessage(message) > 0)) {
     UnitAssert(nameServer.ReceiveMessage(message));
     UnitAssert(message.Questions().size() > 0);
@@ -153,9 +147,7 @@ void TestGooglePTR()
                                  Dns::MessageQuestion::k_classIN);
   message.Questions().push_back(question);
 
-  in_addr  inAddr;
-  inet_pton(AF_INET, "8.8.8.8", &inAddr);
-  Dns::NameServer  nameServer(inAddr);
+  Dns::NameServer  nameServer(Ipv4Address("8.8.8.8"));
   if (UnitAssert(nameServer.SendMessage(message) > 0)) {
     UnitAssert(nameServer.ReceiveMessage(message));
     UnitAssert(message.Questions().size() > 0);
@@ -182,9 +174,7 @@ void TestTwitCNAME()
                                  Dns::MessageQuestion::k_classIN);
   message.Questions().push_back(question);
 
-  in_addr  inAddr;
-  inet_pton(AF_INET, "8.8.8.8", &inAddr);
-  Dns::NameServer  nameServer(inAddr);
+  Dns::NameServer  nameServer(Ipv4Address("8.8.8.8"));
   if (UnitAssert(nameServer.SendMessage(message) > 0)) {
     UnitAssert(nameServer.ReceiveMessage(message));
     UnitAssert(message.Questions().size() > 0);
@@ -211,9 +201,7 @@ void TestGRCCAA()
                                  Dns::MessageQuestion::k_classIN);
   message.Questions().push_back(question);
 
-  in_addr  inAddr;
-  inet_pton(AF_INET, "8.8.8.8", &inAddr);
-  Dns::NameServer  nameServer(inAddr);
+  Dns::NameServer  nameServer(Ipv4Address("8.8.8.8"));
   if (UnitAssert(nameServer.SendMessage(message) > 0)) {
     UnitAssert(nameServer.ReceiveMessage(message));
     UnitAssert(message.Questions().size() > 0);
@@ -242,9 +230,7 @@ void TestIETFDNSKEY()
   message.Questions().push_back(question);
   message.EnableEDNS(4096, false);
   
-  in_addr  inAddr;
-  inet_pton(AF_INET, "8.8.8.8", &inAddr);
-  Dns::NameServer  nameServer(inAddr);
+  Dns::NameServer  nameServer(Ipv4Address("8.8.8.8"));
   if (UnitAssert(nameServer.SendMessage(message) > 0)) {
     UnitAssert(nameServer.ReceiveMessage(message));
     UnitAssert(message.Questions().size() > 0);
@@ -272,9 +258,7 @@ void TestIETFNSEC()
   message.Questions().push_back(question);
   //  message.EnableEDNS(4096, false);
   
-  in_addr  inAddr;
-  inet_pton(AF_INET, "8.8.8.8", &inAddr);
-  Dns::NameServer  nameServer(inAddr);
+  Dns::NameServer  nameServer(Ipv4Address("8.8.8.8"));
   if (UnitAssert(nameServer.SendMessage(message) > 0)) {
     UnitAssert(nameServer.ReceiveMessage(message));
     UnitAssert(message.Questions().size() > 0);
@@ -303,9 +287,7 @@ void TestTcpIETFRRSIG()
   message.Questions().push_back(question);
   message.EnableEDNS(4096, true);
   
-  in_addr  inAddr;
-  inet_pton(AF_INET, "8.8.8.8", &inAddr);
-  Dns::NameServer  nameServer(inAddr);
+  Dns::NameServer  nameServer(Ipv4Address("8.8.8.8"));
   if (UnitAssert(nameServer.WriteMessage(message))) {
     UnitAssert(nameServer.ReadMessage(message));
     UnitAssert(message.Questions().size() > 0);
@@ -334,9 +316,7 @@ void TestIETFRRSIG()
   message.Questions().push_back(question);
   message.EnableEDNS(4096, true);
   
-  in_addr  inAddr;
-  inet_pton(AF_INET, "8.8.8.8", &inAddr);
-  Dns::NameServer  nameServer(inAddr);
+  Dns::NameServer  nameServer(Ipv4Address("8.8.8.8"));
   if (UnitAssert(nameServer.SendMessage(message) > 0)) {
     UnitAssert(nameServer.ReceiveMessage(message));
     UnitAssert(message.Questions().size() > 0);
@@ -364,9 +344,7 @@ void TestIETFDS()
                                  Dns::MessageQuestion::k_classIN);
   message.Questions().push_back(question);
   
-  in_addr  inAddr;
-  inet_pton(AF_INET, "8.8.8.8", &inAddr);
-  Dns::NameServer  nameServer(inAddr);
+  Dns::NameServer  nameServer(Ipv4Address("8.8.8.8"));
   if (UnitAssert(nameServer.SendMessage(message) > 0)) {
     UnitAssert(nameServer.ReceiveMessage(message));
     UnitAssert(message.Questions().size() > 0);
@@ -393,9 +371,7 @@ void TestCAIDALOC()
                                  Dns::MessageQuestion::k_classIN);
   message.Questions().push_back(question);
   
-  in_addr  inAddr;
-  inet_pton(AF_INET, "8.8.8.8", &inAddr);
-  Dns::NameServer  nameServer(inAddr);
+  Dns::NameServer  nameServer(Ipv4Address("8.8.8.8"));
   if (UnitAssert(nameServer.SendMessage(message) > 0)) {
     UnitAssert(nameServer.ReceiveMessage(message));
     UnitAssert(message.Questions().size() > 0);
@@ -420,9 +396,7 @@ void TestCAIDATXT()
                                  Dns::MessageQuestion::k_classIN);
   message.Questions().push_back(question);
   
-  in_addr  inAddr;
-  inet_pton(AF_INET, "8.8.8.8", &inAddr);
-  Dns::NameServer  nameServer(inAddr);
+  Dns::NameServer  nameServer(Ipv4Address("8.8.8.8"));
   if (UnitAssert(nameServer.SendMessage(message) > 0)) {
     UnitAssert(nameServer.ReceiveMessage(message));
     UnitAssert(message.Questions().size() > 0);
@@ -449,9 +423,7 @@ void TestMCPLEXMX()
                                  Dns::MessageQuestion::k_classIN);
   message.Questions().push_back(question);
   
-  in_addr  inAddr;
-  inet_pton(AF_INET, "8.8.8.8", &inAddr);
-  Dns::NameServer  nameServer(inAddr);
+  Dns::NameServer  nameServer(Ipv4Address("8.8.8.8"));
   if (UnitAssert(nameServer.SendMessage(message) > 0)) {
     UnitAssert(nameServer.ReceiveMessage(message));
     UnitAssert(message.Questions().size() > 0);
@@ -478,9 +450,7 @@ void TestJUNCTIONSRV()
                                  Dns::MessageQuestion::k_classIN);
   message.Questions().push_back(question);
   
-  in_addr  inAddr;
-  inet_pton(AF_INET, "8.8.8.8", &inAddr);
-  Dns::NameServer  nameServer(inAddr);
+  Dns::NameServer  nameServer(Ipv4Address("8.8.8.8"));
   if (UnitAssert(nameServer.SendMessage(message) > 0)) {
     UnitAssert(nameServer.ReceiveMessage(message));
     UnitAssert(message.Questions().size() > 0);
